@@ -273,8 +273,16 @@ basepath = os.path.expanduser('~/share/bby/')
     const domain = isDev ? 'dev.boyuai.com' : 'boyuai.com';
 
     const userId = Number(baseRegRes[2]);
+    const content = Jupyter.notebook.toJSON();
+    content.cells.forEach((c) => {
+      if (c.outputs) {
+        c.outputs = [];
+        c.execution_count = null;
+      }
+      c.metadata = {};
+    });
     const body = {
-      content: Jupyter.notebook.toJSON(),
+      content,
       userId,
       token,
     };
@@ -283,10 +291,10 @@ basepath = os.path.expanduser('~/share/bby/')
     $.ajax({
       url: `https://${domain}/api/v1${path}`,
       type: 'PUT',
-      dataType: 'json', // Set datatype - affects Accept header
-      data: JSON.stringify(body), // Some data e.g. Valid JSON as a string
+      dataType: 'json',
+      data: JSON.stringify(body),
       contentType: 'application/json',
-      success(result) {
+      success() {
         alert('同步成功，请刷新波波鱼步骤页后查看，中途请不要运行代码');
       },
       error() {
